# similarity-engine-utils

Utility tools for easier management of feature-vector database and similar 
vector comparison

## Installation
---------------

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install library.

```bash
pip install similarity-engine-utils
```
